@@ -160,7 +160,7 @@ class Ready(BaseEvent):
     """
     The client is now ready.
 
-    Note:
+    !!! note
         Don't use this event for things that must only happen once, on startup, as this event may be called multiple times.
         Instead, use the `Startup` event
 
