@@ -2,6 +2,7 @@ import copy
 from typing import TYPE_CHECKING
 
 import naff.api.events as events
+from naff.models.discord.channel import BaseChannel
 from naff.models.discord.invite import Invite
 from naff.client.const import MISSING
 from ._template import EventMixinTemplate, Processor
@@ -20,11 +21,10 @@ class ChannelEvents(EventMixinTemplate):
 
     @Processor.define()
     async def _on_raw_channel_delete(self, event: "RawGatewayEvent") -> None:
-        # for some reason this event returns the deleted object?
-        # so we cache it regardless
-        channel = self.cache.place_channel_data(event.data)
-        if guild := getattr(channel, "guild", None):
-            guild._channel_ids.discard(channel.id)
+        # for some reason this event returns the deleted channel data?
+        # so we create an object from it
+        channel = BaseChannel.from_dict_factory(event.data, self)
+        self.cache.delete_channel(event.data.get("id"))
         self.dispatch(events.ChannelDelete(channel))
 
     @Processor.define()
